pub(crate) enum DataReencryptionError {
Decryption,
Encryption,
DataConversion,
CipherKeyRewrap,
}Expand description
Errors that can occur during data re-encryption
Variants
Decryption
Failed to decrypt data with the current user key
Encryption
Failed to encrypt data with the new user key
DataConversion
Failed to convert data to API model
CipherKeyRewrap
CipherKeyRewrap