check_for_old_attachments

Function check_for_old_attachments 

pub(super) fn check_for_old_attachments(
    ciphers: &[Cipher],
) -> Result<(), RotateUserKeysError>
Checks that no cipher contains legacy attachments (attachments where key is None). Ciphers with old attachments cannot be safely re-encrypted during key rotation because the attachment file contents are encrypted directly with the user key and would become irrecoverable after the user key change.