reencrypt_data

Function reencrypt_data 

pub(super) fn reencrypt_data(
    folders: &[Folder],
    ciphers: &[Cipher],
    sends: &[Send],
    current_user_key_id: SymmetricKeyId,
    new_user_key_id: SymmetricKeyId,
    ctx: &mut KeyStoreContext<'_, KeyIds>,
) -> Result<AccountDataRequestModel, DataReencryptionError>
Re-encrypts all user data (folders, ciphers, sends) with the new user key for the purpose of key-rotation. Note: Ciphers must be filtered to just contain the user’s ciphers, not organization ciphers.